@@ -19,6 +19,12 @@
 
 #include <config.h>
 
+/* needed for db.h with 'gcc -ansi -pedantic' */
+#ifndef _BSD_SOURCE
+#  define _BSD_SOURCE 1
+#endif
+#include <sys/types.h>
+
 #ifdef HAVE_DB_185_H
 # include <db_185.h>
 #else
