@@ -18,6 +18,7 @@
 #include <errno.h>
 #include <signal.h>
 #include <gtk/gtk.h>
+#include <gdk/gdkkeysyms.h>
 #include "libgnome/libgnomeP.h"
 #include "gnome-calculator.h"
 #include "gnome-pixmap.h"
@@ -64,7 +65,8 @@ struct _CalculatorButton {
 	gpointer data;
 	gpointer invdata;
 	gint convert_to_rad;
-	char key; /*key shortcut*/
+	guint key; /*key shortcut*/
+	guint key2; /*2nd key shortcut - keypad or such*/
 };
 
 typedef void (*GnomeCalcualtorResultChangedSignal) (GtkObject * object,
@@ -1081,53 +1083,53 @@ gnome_calculator_realized(GtkWidget *w, gpointer data)
 
 static const CalculatorButton buttons[8][5] = {
 	{
-		{N_("1/x"),(GtkSignalFunc)simple_func,c_inv,NULL,FALSE,0},
-		{N_("x^2"),(GtkSignalFunc)simple_func,c_pow2,sqrt,FALSE,0},
-		{N_("SQRT"),(GtkSignalFunc)simple_func,sqrt,c_pow2,FALSE,0},
-		{N_("CE/C"),(GtkSignalFunc)clear_calc,NULL,NULL,FALSE,0},
-		{N_("AC"),(GtkSignalFunc)reset_calc,NULL,NULL,FALSE,0}
+		{N_("1/x"),(GtkSignalFunc)simple_func,c_inv,NULL,FALSE,0,0},
+		{N_("x^2"),(GtkSignalFunc)simple_func,c_pow2,sqrt,FALSE,0,0},
+		{N_("SQRT"),(GtkSignalFunc)simple_func,sqrt,c_pow2,FALSE,0,0},
+		{N_("CE/C"),(GtkSignalFunc)clear_calc,NULL,NULL,FALSE,0,0},
+		{N_("AC"),(GtkSignalFunc)reset_calc,NULL,NULL,FALSE,0,0}
 	},{
 		{NULL,NULL,NULL,NULL}, /*inverse button*/
-		{N_("sin"),(GtkSignalFunc)simple_func,sin,asin,TRUE,0},
-		{N_("cos"),(GtkSignalFunc)simple_func,cos,acos,TRUE,0},
-		{N_("tan"),(GtkSignalFunc)simple_func,tan,atan,TRUE,0},
-		{N_("DEG"),(GtkSignalFunc)drg_toggle,NULL,NULL,FALSE,0}
+		{N_("sin"),(GtkSignalFunc)simple_func,sin,asin,TRUE,0,0},
+		{N_("cos"),(GtkSignalFunc)simple_func,cos,acos,TRUE,0,0},
+		{N_("tan"),(GtkSignalFunc)simple_func,tan,atan,TRUE,0,0},
+		{N_("DEG"),(GtkSignalFunc)drg_toggle,NULL,NULL,FALSE,0,0}
 	},{
-		{N_("e"),(GtkSignalFunc)set_e,NULL,NULL,FALSE,0},
-		{N_("EE"),(GtkSignalFunc)add_digit,"e+",NULL,FALSE,0},
-		{N_("log"),(GtkSignalFunc)simple_func,log10,c_pow10,FALSE,0},
-		{N_("ln"),(GtkSignalFunc)simple_func,log,c_powe,FALSE,0},
-		{N_("x^y"),(GtkSignalFunc)math_func,pow,NULL,FALSE,'^'}
+		{N_("e"),(GtkSignalFunc)set_e,NULL,NULL,FALSE,0,0},
+		{N_("EE"),(GtkSignalFunc)add_digit,"e+",NULL,FALSE,0,0},
+		{N_("log"),(GtkSignalFunc)simple_func,log10,c_pow10,FALSE,0,0},
+		{N_("ln"),(GtkSignalFunc)simple_func,log,c_powe,FALSE,0,0},
+		{N_("x^y"),(GtkSignalFunc)math_func,pow,NULL,FALSE,'^',0}
 	},{
-		{N_("PI"),(GtkSignalFunc)set_pi,NULL,NULL,FALSE,0},
-		{N_("x!"),(GtkSignalFunc)simple_func,c_fact,NULL,FALSE,'!'},
-		{N_("("),(GtkSignalFunc)add_parenth,NULL,NULL,FALSE,'('},
-		{N_(")"),(GtkSignalFunc)sub_parenth,NULL,NULL,FALSE,')'},
-		{N_("/"),(GtkSignalFunc)math_func,c_div,NULL,FALSE,'/'}
+		{N_("PI"),(GtkSignalFunc)set_pi,NULL,NULL,FALSE,0,0},
+		{N_("x!"),(GtkSignalFunc)simple_func,c_fact,NULL,FALSE,'!',0},
+		{N_("("),(GtkSignalFunc)add_parenth,NULL,NULL,FALSE,'(',0},
+		{N_(")"),(GtkSignalFunc)sub_parenth,NULL,NULL,FALSE,')',0},
+		{N_("/"),(GtkSignalFunc)math_func,c_div,NULL,FALSE,'/',GDK_KP_Divide}
 	},{
-		{N_("STO"),(GtkSignalFunc)store_m,NULL,NULL,FALSE,0},
-		{N_("7"),(GtkSignalFunc)add_digit,NULL,NULL,FALSE,'7'},
-		{N_("8"),(GtkSignalFunc)add_digit,NULL,NULL,FALSE,'8'},
-		{N_("9"),(GtkSignalFunc)add_digit,NULL,NULL,FALSE,'9'},
-		{N_("*"),(GtkSignalFunc)math_func,c_mul,NULL,FALSE,'*'}
+		{N_("STO"),(GtkSignalFunc)store_m,NULL,NULL,FALSE,0,0},
+		{N_("7"),(GtkSignalFunc)add_digit,NULL,NULL,FALSE,'7',GDK_KP_7},
+		{N_("8"),(GtkSignalFunc)add_digit,NULL,NULL,FALSE,'8',GDK_KP_8},
+		{N_("9"),(GtkSignalFunc)add_digit,NULL,NULL,FALSE,'9',GDK_KP_9},
+		{N_("*"),(GtkSignalFunc)math_func,c_mul,NULL,FALSE,'*',GDK_KP_Multiply}
 	},{
-		{N_("RCL"),(GtkSignalFunc)recall_m,NULL,NULL,FALSE,0},
-		{N_("4"),(GtkSignalFunc)add_digit,NULL,NULL,FALSE,'4'},
-		{N_("5"),(GtkSignalFunc)add_digit,NULL,NULL,FALSE,'5'},
-		{N_("6"),(GtkSignalFunc)add_digit,NULL,NULL,FALSE,'6'},
-		{N_("-"),(GtkSignalFunc)math_func,c_sub,NULL,FALSE,'-'}
+		{N_("RCL"),(GtkSignalFunc)recall_m,NULL,NULL,FALSE,0,0},
+		{N_("4"),(GtkSignalFunc)add_digit,NULL,NULL,FALSE,'4',GDK_KP_4},
+		{N_("5"),(GtkSignalFunc)add_digit,NULL,NULL,FALSE,'5',GDK_KP_5},
+		{N_("6"),(GtkSignalFunc)add_digit,NULL,NULL,FALSE,'6',GDK_KP_6},
+		{N_("-"),(GtkSignalFunc)math_func,c_sub,NULL,FALSE,'-',GDK_KP_Subtract}
 	},{
-		{N_("SUM"),(GtkSignalFunc)sum_m,NULL,NULL,FALSE,0},
-		{N_("1"),(GtkSignalFunc)add_digit,NULL,NULL,FALSE,'1'},
-		{N_("2"),(GtkSignalFunc)add_digit,NULL,NULL,FALSE,'2'},
-		{N_("3"),(GtkSignalFunc)add_digit,NULL,NULL,FALSE,'3'},
-		{N_("+"),(GtkSignalFunc)math_func,c_add,NULL,FALSE,'+'}
+		{N_("SUM"),(GtkSignalFunc)sum_m,NULL,NULL,FALSE,0,0},
+		{N_("1"),(GtkSignalFunc)add_digit,NULL,NULL,FALSE,'1',GDK_KP_1},
+		{N_("2"),(GtkSignalFunc)add_digit,NULL,NULL,FALSE,'2',GDK_KP_2},
+		{N_("3"),(GtkSignalFunc)add_digit,NULL,NULL,FALSE,'3',GDK_KP_3},
+		{N_("+"),(GtkSignalFunc)math_func,c_add,NULL,FALSE,'+',GDK_KP_Add}
 	},{
 		{N_("EXC"),(GtkSignalFunc)exchange_m,NULL,NULL,FALSE,0},
-		{N_("0"),(GtkSignalFunc)add_digit,NULL,NULL,FALSE,'0'},
-		{N_("."),(GtkSignalFunc)add_digit,NULL,NULL,FALSE,'.'},
-		{N_("+/-"),(GtkSignalFunc)negate_val,c_neg,NULL,FALSE,0},
-		{N_("="),(GtkSignalFunc)no_func,NULL,NULL,FALSE,'='}
+		{N_("0"),(GtkSignalFunc)add_digit,NULL,NULL,FALSE,'0',GDK_KP_0},
+		{N_("."),(GtkSignalFunc)add_digit,NULL,NULL,FALSE,'.',GDK_KP_Decimal},
+		{N_("+/-"),(GtkSignalFunc)negate_val,c_neg,NULL,FALSE,0,0},
+		{N_("="),(GtkSignalFunc)no_func,NULL,NULL,FALSE,'=',GDK_KP_Enter}
 	}
 };
 
@@ -1185,6 +1187,26 @@ gnome_calculator_init (GnomeCalculator *gc)
 							     GDK_LOCK_MASK,
 							     GTK_ACCEL_VISIBLE);
 				}
+				if(but->key2)
+				{
+				  gtk_widget_add_accelerator(w,
+							     "clicked",
+							     gc->accel,
+							     but->key2,0,
+							     0);
+				  gtk_widget_add_accelerator(w,
+							     "clicked",
+							     gc->accel,
+							     but->key2,
+							     GDK_SHIFT_MASK,
+							     0);
+				  gtk_widget_add_accelerator(w,
+							     "clicked",
+							     gc->accel,
+							     but->key2,
+							     GDK_LOCK_MASK,
+							     GTK_ACCEL_VISIBLE);
+				}
 
 				gtk_object_set_user_data(GTK_OBJECT(w),gc);
 				gtk_widget_show(w);
