@@ -536,6 +536,9 @@ icon_event (Gil *gil, Icon *icon, GdkEvent *event)
 	switch (event->type){
 	case GDK_BUTTON_PRESS:
 		gil->last_clicked = icon;
+
+		if (event->button.button > 3)
+			return FALSE;
 		
 		if (icon->text->selected && (event->button.button == 1 || event->button.button == 3)){
 			gil->last_clicked = icon;
@@ -560,6 +563,9 @@ icon_event (Gil *gil, Icon *icon, GdkEvent *event)
 		if (gil->last_clicked == NULL)
 			return FALSE;
 
+		if (event->button.button > 3)
+			return FALSE;
+
 		toggle_icon (gil, gil->last_clicked, event);
 		return TRUE;
 
@@ -955,6 +961,11 @@ gil_destroy (GtkObject *object)
 	gil->dirty  = TRUE;
 	gnome_icon_list_clear (gil);
 
+	if (gil->timer_tag != -1) {
+		gtk_timeout_remove (gil->timer_tag);
+		gil->timer_tag = -1;
+	}
+
 	if (gil->adj)
 		gtk_object_unref (GTK_OBJECT (gil->adj));
 	if (gil->hadj)
