@@ -245,6 +245,14 @@ static void vt_line_update(struct _vtx *vx, struct vt_line *l, int line, int alw
       bl->data[i] = l->data[i];
     }
 
+    /* hide rendering of text (make forground=background)*/
+    if (newattr & VTATTR_CONCEALED) {
+      if (newattr & VTATTR_REVERSE)
+	newattr = (newattr&~VTATTR_BACKCOLOURM)|((newattr&VTATTR_FORECOLOURM)>>(VTATTR_FORECOLOURB-VTATTR_BACKCOLOURB));
+      else
+	newattr = (newattr&~VTATTR_FORECOLOURM)|((newattr&VTATTR_BACKCOLOURM)<<(VTATTR_FORECOLOURB-VTATTR_BACKCOLOURB));
+    }
+
     if (run == 0) {
       runstart = i;
       p = vx->runbuffer;
@@ -786,7 +794,7 @@ void vt_fix_selection(struct _vtx *vx)
     /* scan back over word chars */
     d(printf("startx = %d %p-> \n", sx, s->data));
 
-    if (ex==sx && ex<e->width)
+    if (ex==sx && ex<e->width && sy==ey)
       ex++;
 
     if ((s->data[sx]&0xff)==0) {
@@ -821,7 +829,7 @@ void vt_fix_selection(struct _vtx *vx)
   default:
     d(printf("selecting by char\n"));
 
-    if (ex==sx && ex<e->width)
+    if (ex==sx && ex<e->width && sy==ey)
       ex++;
 
     if ((s->data[sx]&0xff)==0) {
@@ -856,7 +864,7 @@ static char *vt_expand_line(struct vt_line *l, int start, int end, char *out)
 {
   int i;
   char *o;
-  char c;
+  unsigned char c;
   int state=0;
   int dataend=0;
   int lf=0;
